==> sceptre-00.317.tar.gz: x3/xosini.f <==
      SUBROUTINE XOSINI (MAXI4,MAXR4,MAXL4,MAXC6,MAXR8,MAXCH) 
 
C Author ...: Wolf-Rainer Novender
C Date .....: 10-JAN-90 / 2000-08-20
C Remarks ..: Verwaltungssystem fuer Vektoren und Variablen im 
C             internen Speicher 
C last updt.:  6-JUL-90 (neuer Parameter NADR in XOSTOR) 
C	2000-08-20: 3spaltige Ausgabe fuer PRINT
 
      PARAMETER (MAXTAB=700,maxcol=3) 
 
      CHARACTER*8   WNAME(0:MAXTAB) 
      INTEGER       KTYP (0:MAXTAB) 
      INTEGER       KLEN (0:MAXTAB) 
      INTEGER       KADR (0:MAXTAB) 
      LOGICAL       LERROR 
      CHARACTER*(*) WCMD,WSN 
      INTEGER       ITKLEN(0:9) 
 
      CHARACTER WHEAD1*32,WHEAD2*32,WLINE(maxcol)*32 
      DATA WHEAD1 /' Nr. Name    Typ  Lnge Adresse'/ 
      DATA WHEAD2 /' ______________________________'/ 
 
      DO 1 I=0,MAXTAB 
         WNAME(I)=' ' 
         KTYP (I)=0 
         KLEN (I)=0 
         KADR (I)=0 
    1 CONTINUE 
 
      KLEN (0) = MAXTAB 
      KADR (0) = 9 
 
      WNAME(3) = 'I4XXXX' 
      KTYP (3) = 3 
      KLEN (3) = MAXI4 
 
      WNAME(4) = 'R4XXXX' 
      KTYP (4) = 4 
      KLEN (4) = MAXR4 
 
      WNAME(5) = 'L4XXXX' 
      KTYP (5) = 5 
      KLEN (5) = MAXL4 
 
      WNAME(6) = 'C6XXXX' 
      KTYP (6) = 6 
      KLEN (6) = MAXC6 
 
      WNAME(8) = 'R8XXXX' 
      KTYP (8) = 8 
      KLEN (8) = MAXR8 
 
      WNAME(9) = 'CHXXXX' 
      KTYP (9) = 9 
      KLEN (9) = MAXCH 
 
      GO TO 9999 
 
      ENTRY XOS000 (WCMD,LERROR) 
 
      IF (WCMD.EQ.'PRINT') THEN 
         LERROR=.TRUE. 
         WRITE (*,'(''0'',A,1X,A,1X,A,1X,A)') (WHEAD1,J=1,maxcol) 
         WRITE (*,'('' '',A,1X,A,1X,A,1X,A)') (WHEAD2,J=1,maxcol) 
         MAXADR=KADR(0) 
         NZ=(MAXADR)/maxcol + 1 
         DO 2 I=0,NZ-1 
            WLINE(2)=' ' 
            WLINE(3)=' ' 
C          WLINE(4)=' ' 
            K1=I 
            WRITE (WLINE(1),'(I4,1X,A8,I2,I8,I8)') 
     *            K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
            K1=NZ+I 
            IF (K1.LE.MAXADR) 
     *         WRITE (WLINE(2),'(I4,1X,A8,I2,I8,I8)') 
     *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
            K1=2*NZ+I 
            IF (K1.LE.MAXADR) 
     *         WRITE (WLINE(3),'(I4,1X,A8,I2,I8,I8)') 
     *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
C            K1=3*NZ+I 
C            IF (K1.LE.MAXADR) 
C     *         WRITE (WLINE(4),'(I4,1X,A8,I2,I8,I8)') 
C     *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
            WRITE (*,'(1X,A,''|'',A,''|'',A)') (WLINE(J),J=1,maxcol) 
    2    CONTINUE 
         WRITE (*,*) 
         LERROR=.FALSE. 
         GO TO 9999 
      END IF 
 
      IF (WCMD.EQ.'DUMP') THEN 
         ITEMP = (KADR(0)+1) * 8 
         CALL POSWC1 ('XOSNAME',WNAME,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSTYP',KTYP,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSLEN',KLEN,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSADR',KADR,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
      END IF 
 
      IF (WCMD.EQ.'LOAD') THEN 
         ITEMP = MAXTAB * 8 
         CALL POSRC1 ('XOSNAME',WNAME,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSTYP',KTYP,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         DO 5 I=0,9 
            ITKLEN(I)=KLEN(I) 
    5    CONTINUE 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSLEN',KLEN,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         DO 6 I=0,9 
            IF (ITKLEN(I).LT.KLEN(I)) THEN 
               WRITE (*,'(''0XOS000 - LOAD - '', 
     *         ''zu wenig Speicherpltze reserviert fr '', 
     *         ''Typ'',I2,'', initialisiert mit'',I8, 
     *         '', zurckgeladen mit'',I8)') I,ITKLEN(I),KLEN(I) 
               LERROR=.TRUE. 
            END IF 
    6    CONTINUE 
         DO 7 I=0,9 
            KLEN(I)=ITKLEN(I) 
    7    CONTINUE 
         IF (LERROR) GO TO 9999 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSADR',KADR,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
      END IF 
 
      GO TO 9999 
 
      ENTRY XOSFRE (NTYP,MAXLEN,NADR,LERROR) 
 
C   NTYP  : Art des COMMON-Blocks (Vorgabe) 
C   MAXLEN: maximal verfgbarer (freier) Bereich (Ergebnis) 
C   NADR  : Anfangsadresse des verfgbaren Bereiches (Ergebnis) 
C   LERROR: Fehlerausgang 
 
      LERROR=.TRUE. 
      MAXLEN = 0 
      NADR = 0 
      IF (NTYP.LE.0 .OR. NTYP.GE.10) THEN 
         WRITE (*,'(''0XOSFRE - NTYP ungltig, NTYP='',I10)') NTYP 
         GO TO 9999 
      END IF 
      MAXLEN = KLEN(NTYP)-KADR(NTYP) 
      IF (MAXLEN.LE.0) THEN 
         WRITE (*,'(''0XOSFRE - kein freier Speicherplatz vorhanden,'', 
     *         '' NTYP='',I2)') NTYP 
         GO TO 9999 
      END IF 
      NADR = KADR(NTYP)+1 
      LERROR=.FALSE. 
      GO TO 9999 
 
      ENTRY XOSTOR (WSN,NTYP,NLEN,NADR,LERROR) 
 
C     WSN   : symbolischer Name (Vorgabe) 
C     NTYP  : Art des COMMON-Blocks (Vorgabe) 
C     NLEN  : tatschliche Lnge (Vorgabe) 
C     NADR  : Anfangsadresse (Ergebnis) 
C     LERROR: Fehlerausgang 
 
      LERROR=.TRUE. 
 
      IF (NTYP.LE.0 .OR. NTYP.GE.10) THEN 
         WRITE (*,'(''0XOSTOR - NTYP ungltig, NTYP='',I10)') NTYP 
         GO TO 9999 
      END IF 
 
      IF ((KADR(NTYP)+NLEN).GT.KLEN(NTYP)) THEN 
         WRITE (*,'(''0XOSTOR - bentigter Speicherplatz nicht vor'', 
     *         ''handen; NTYP='',I2,'', WSN='',A,/, 
     *         '', NLEN= '',I8,'', FREI='',I8)') 
     *         NTYP,WSN,NLEN,KLEN(NTYP)-KADR(NTYP) 
         GO TO 9999 
      END IF 
 
      MAXADR=KADR(0) 
      DO 3 I=10,MAXADR 
         IF (WNAME(I).EQ.WSN .AND. KTYP(I).EQ.NTYP) THEN 
         WRITE (*,'(''0XOSTOR - Komponente mit gleichem Namen schon'', 
     *         '' vorhanden; WSN='',A,'', NTYP='',I2)') WSN,NTYP 
         GO TO 9999 
      END IF 
    3 CONTINUE 
 
      IF ((MAXADR+1).GT.KLEN(0)) THEN 
         WRITE (*,'(''0XOSTOR - Tabellenberlauf, mehr als MAXTAB='', 
     *         I5,'' Eintrge'')') KLEN(0) 
         GO TO 9999 
      END IF 
 
      MAXADR=MAXADR+1 
      KADR(0)=MAXADR 
      WNAME(MAXADR)=WSN 
      KTYP(MAXADR)=NTYP 
      KLEN(MAXADR)=NLEN 
      KADR(MAXADR)=KADR(NTYP)+1 
      NADR = KADR(MAXADR) 
      KADR(NTYP)=KADR(NTYP)+NLEN 
      WRITE (*,'('' XOSTOR - "'',A,''" ---> Position '', 
     *      I5,'', KTYP='',I2,'', KLEN='',I8,'', KADR='', 
     *      I8)') WSN,MAXADR,KTYP(MAXADR),KLEN(MAXADR),KADR(MAXADR) 
      LERROR=.FALSE. 
      GO TO 9999 
 
      ENTRY XOSRCH (WSN,NTYP,NLEN,NADR,LERROR) 
 
C     WSN   : symbolischer Name (Vorgabe) 
C     NTYP  : Art des COMMON-Blocks (Vorgabe) 
C     NLEN  : tatschliche Lnge (Ergebnis) 
C     NADR  : Anfangsadresse (Ergebnis) 
C     LERROR: Fehlerausgang, falls nicht vorhanden 
 
      LERROR=.TRUE. 
      MAXADR=KADR(0) 
      DO 4 I=10,MAXADR 
         IF (WNAME(I).EQ.WSN .AND. KTYP(I).EQ.NTYP) THEN 
            NLEN=KLEN(I) 
            NADR=KADR(I) 
            LERROR=.FALSE. 
            GO TO 9999 
         END IF 
    4 CONTINUE 
 
      WRITE (*,'('' XOSRCH - Komponente nicht gefunden; WSN="'',A, 
     *      ''", NTYP='',I2)') WSN,NTYP 
      GO TO 9999 
 
 9999 RETURN 
 
      END

==> sceptre-2012.061.tar.gz: x3/xosini.f <==
      SUBROUTINE XOSINI (MAXI4,MAXR4,MAXL4,MAXC6,MAXR8,MAXCH) 
 
C Author ...: Wolf-Rainer Novender
C Date .....: 10-JAN-90 / 2000-08-20
C Remarks ..: Verwaltungssystem fuer Vektoren und Variablen im 
C             internen Speicher 
C last updt.:  6-JUL-90 (neuer Parameter NADR in XOSTOR) 
C  2000-08-20: 3spaltige Ausgabe fuer PRINT
C  2002-12-20: 2spaltige Ausgabe fr PRINT
C  2006-08-11: Versionsangabe, XOSTOR Drucken abgeschaltet
C  2007-12-11: symb. Namen d"urfen nur einmal vorkommen, unabh"angig vom Typ
 
      PARAMETER (MAXTAB=700,maxcol=2,version=1.2,nwr=6) 
 
      character     wpname*8 /'XOSINI'/
      CHARACTER*8   WNAME(0:MAXTAB) 
      INTEGER       KTYP (0:MAXTAB) 
      INTEGER       KLEN (0:MAXTAB) 
      INTEGER       KADR (0:MAXTAB) 
      LOGICAL       LERROR 
      CHARACTER*(*) WCMD,WSN 
      INTEGER       ITKLEN(0:9) 
 
      CHARACTER WHEAD1*32,WHEAD2*32,WLINE(maxcol)*32 
      DATA WHEAD1 /' Nr. Name    Typ  Länge Adresse'/ 
      DATA WHEAD2 /' ______________________________'/ 
 
      DO 1 I=0,MAXTAB 
         WNAME(I)=' ' 
         KTYP (I)=0 
         KLEN (I)=0 
         KADR (I)=0 
    1 CONTINUE 
 
      KLEN (0) = MAXTAB 
      KADR (0) = 9 
 
      WNAME(3) = 'I4XXXX' 
      KTYP (3) = 3 
      KLEN (3) = MAXI4 
 
      WNAME(4) = 'R4XXXX' 
      KTYP (4) = 4 
      KLEN (4) = MAXR4 
 
      WNAME(5) = 'L4XXXX' 
      KTYP (5) = 5 
      KLEN (5) = MAXL4 
 
      WNAME(6) = 'C6XXXX' 
      KTYP (6) = 6 
      KLEN (6) = MAXC6 
 
      WNAME(8) = 'R8XXXX' 
      KTYP (8) = 8 
      KLEN (8) = MAXR8 
 
      WNAME(9) = 'CHXXXX' 
      KTYP (9) = 9 
      KLEN (9) = MAXCH 
 
      write (nwr,'(a,"- Version ",f5.2,"; Initialisierung, maxtab=",
     *      i6)') wpname,version,maxtab 
      GO TO 9999 
 
      ENTRY XOS000 (WCMD,LERROR) 
 
      IF (WCMD.EQ.'PRINT') THEN 
         LERROR=.TRUE. 
         WRITE (nwr,'(A,1X,A,1X,A,1X,A)') (WHEAD1,J=1,maxcol) 
         WRITE (nwr,'(A,1X,A,1X,A,1X,A)') (WHEAD2,J=1,maxcol) 
         MAXADR=KADR(0) 
         NZ=(MAXADR)/maxcol + 1 
         DO 2 I=0,NZ-1 
            WLINE(2)=' ' 
C           WLINE(3)=' ' 
C           WLINE(4)=' ' 
            K1=I 
            WRITE (WLINE(1),'(I4,1X,A8,I2,I8,I8)') 
     *            K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
            K1=NZ+I 
            IF (K1.LE.MAXADR) 
     *         WRITE (WLINE(2),'(I4,1X,A8,I2,I8,I8)') 
     *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
C           K1=2*NZ+I 
C           IF (K1.LE.MAXADR) 
C    *         WRITE (WLINE(3),'(I4,1X,A8,I2,I8,I8)') 
C    *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
C            K1=3*NZ+I 
C            IF (K1.LE.MAXADR) 
C     *         WRITE (WLINE(4),'(I4,1X,A8,I2,I8,I8)') 
C     *               K1, WNAME(K1),KTYP(K1),KLEN(K1),KADR(K1) 
            WRITE (*,'(1X,A,''|'',A,''|'',A)') (WLINE(J),J=1,maxcol) 
    2    CONTINUE 
         WRITE (nwr,*) 
         LERROR=.FALSE. 
         GO TO 9999 
      END IF 
 
      IF (WCMD.EQ.'DUMP') THEN 
         ITEMP = (KADR(0)+1) * 8 
         CALL POSWC1 ('XOSNAME',WNAME,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSTYP',KTYP,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSLEN',KLEN,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = KADR(0) + 1 
         CALL POSWI4 ('XOSADR',KADR,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
      END IF 
 
      IF (WCMD.EQ.'LOAD') THEN 
         ITEMP = MAXTAB * 8 
         CALL POSRC1 ('XOSNAME',WNAME,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSTYP',KTYP,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         DO 5 I=0,9 
            ITKLEN(I)=KLEN(I) 
    5    CONTINUE 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSLEN',KLEN,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
         DO 6 I=0,9 
            IF (ITKLEN(I).LT.KLEN(I)) THEN 
               WRITE (*,'(''0XOS000 - LOAD - '', 
     *         ''zu wenig Speicherpltze reserviert fr '', 
     *         ''Typ'',I2,'', initialisiert mit'',I8, 
     *         '', zurckgeladen mit'',I8)') I,ITKLEN(I),KLEN(I) 
               LERROR=.TRUE. 
            END IF 
    6    CONTINUE 
         DO 7 I=0,9 
            KLEN(I)=ITKLEN(I) 
    7    CONTINUE 
         IF (LERROR) GO TO 9999 
         ITEMP = MAXTAB 
         CALL POSRI4 ('XOSADR',KADR,ITEMP,LERROR) 
         IF (LERROR) GO TO 9999 
      END IF 
 
      GO TO 9999 
 
      ENTRY XOSFRE (NTYP,MAXLEN,NADR,LERROR) 
 
C   NTYP  : Art des COMMON-Blocks (Vorgabe) 
C   MAXLEN: maximal verfgbarer (freier) Bereich (Ergebnis) 
C   NADR  : Anfangsadresse des verfgbaren Bereiches (Ergebnis) 
C   LERROR: Fehlerausgang 
 
      LERROR=.TRUE. 
      MAXLEN = 0 
      NADR = 0 
      IF (NTYP.LE.0 .OR. NTYP.GE.10) THEN 
         WRITE (*,'(''0XOSFRE - NTYP ungltig, NTYP='',I10)') NTYP 
         GO TO 9999 
      END IF 
      MAXLEN = KLEN(NTYP)-KADR(NTYP) 
      IF (MAXLEN.LE.0) THEN 
         WRITE (*,'(''0XOSFRE - kein freier Speicherplatz vorhanden,'', 
     *         '' NTYP='',I2)') NTYP 
         GO TO 9999 
      END IF 
      NADR = KADR(NTYP)+1 
      LERROR=.FALSE. 
      GO TO 9999 
 
      ENTRY XOSTOR (WSN,NTYP,NLEN,NADR,LERROR) 
 
C     WSN   : symbolischer Name (Vorgabe) 
C     NTYP  : Art des COMMON-Blocks (Vorgabe) 
C     NLEN  : tatschliche Lnge (Vorgabe) 
C     NADR  : Anfangsadresse (Ergebnis) 
C     LERROR: Fehlerausgang 
 
      LERROR=.TRUE. 
 
      IF (NTYP.LE.0 .OR. NTYP.GE.10) THEN 
         WRITE (*,'(''0XOSTOR - NTYP ungltig, NTYP='',I10)') NTYP 
         GO TO 9999 
      END IF 
 
      IF ((KADR(NTYP)+NLEN).GT.KLEN(NTYP)) THEN 
         WRITE (*,'(''0XOSTOR - bentigter Speicherplatz nicht vor'', 
     *         ''handen; NTYP='',I2,'', WSN='',A,/, 
     *         '', NLEN= '',I8,'', FREI='',I8)') 
     *         NTYP,WSN,NLEN,KLEN(NTYP)-KADR(NTYP) 
         GO TO 9999 
      END IF 
 
      MAXADR=KADR(0) 
      DO 3 I=10,MAXADR 
!        IF (WNAME(I).EQ.WSN .AND. KTYP(I).EQ.NTYP) THEN 
         IF (WNAME(I).EQ.WSN) THEN 
         WRITE (*,'(''0XOSTOR - Komponente mit gleichem Namen schon'', 
     *         '' vorhanden; WSN='',A,'', KTYP='',I2)') WSN,KTYP(i) 
         GO TO 9999 
      END IF 
    3 CONTINUE 
 
      IF ((MAXADR+1).GT.KLEN(0)) THEN 
         WRITE (*,'(''0XOSTOR - Tabellenberlauf, mehr als MAXTAB='', 
     *         I5,'' Eintrge'')') KLEN(0) 
         GO TO 9999 
      END IF 
 
      MAXADR=MAXADR+1 
      KADR(0)=MAXADR 
      WNAME(MAXADR)=WSN 
      KTYP(MAXADR)=NTYP 
      KLEN(MAXADR)=NLEN 
      KADR(MAXADR)=KADR(NTYP)+1 
      NADR = KADR(MAXADR) 
      KADR(NTYP)=KADR(NTYP)+NLEN 
c      WRITE (*,'('' XOSTOR - "'',A,''" ---> Position '', 
c     *      I5,'', KTYP='',I2,'', KLEN='',I8,'', KADR='', 
c     *      I8)') WSN,MAXADR,KTYP(MAXADR),KLEN(MAXADR),KADR(MAXADR) 
      LERROR=.FALSE. 
      GO TO 9999 
 
      ENTRY XOSRCH (WSN,NTYP,NLEN,NADR,LERROR) 
 
C     WSN   : symbolischer Name (Vorgabe) 
C     NTYP  : Art des COMMON-Blocks (Ergebnis) 
C     NLEN  : tatschliche Lnge (Ergebnis) 
C     NADR  : Anfangsadresse (Ergebnis) 
C     LERROR: Fehlerausgang, falls nicht vorhanden 
 
      LERROR=.TRUE. 
      MAXADR=KADR(0) 
      DO 4 I=10,MAXADR 
         IF (WNAME(I).EQ.WSN) THEN 
            NLEN=KLEN(I) 
            NADR=KADR(I) 
            ntyp=ktyp(i)
            LERROR=.FALSE. 
            GO TO 9999 
         END IF 
    4 CONTINUE 
 
      WRITE (nwr,'("XOSRCH - Komponente nicht gefunden; WSN=''",A, 
     *      "''")',ADVANCE='NO') trim(WSN)
      GO TO 9999 
 
 9999 RETURN 
 
      END
